# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AlertSeverityResponse(Model):
    """AlertSeverityResponse.

    :param alert_severity_id:
    :type alert_severity_id: int
    :param alert_severity_info:
    :type alert_severity_info: str
    """

    _attribute_map = {
        'alert_severity_id': {'key': 'alertSeverityId', 'type': 'int'},
        'alert_severity_info': {'key': 'alertSeverityInfo', 'type': 'str'},
    }

    def __init__(self, alert_severity_id=None, alert_severity_info=None):
        super(AlertSeverityResponse, self).__init__()
        self.alert_severity_id = alert_severity_id
        self.alert_severity_info = alert_severity_info
