# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RouteMeterEdit(Model):
    """RouteMeterEdit.

    :param display_order: The display order of this route meter
    :type display_order: int
    """

    _attribute_map = {
        'display_order': {'key': 'displayOrder', 'type': 'int'},
    }

    def __init__(self, display_order=None):
        super(RouteMeterEdit, self).__init__()
        self.display_order = display_order
