# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceSizeChild(Model):
    """PlaceSizeChild.

    :param place_size_id:
    :type place_size_id: int
    :param begin_date:
    :type begin_date: datetime
    :param end_date:
    :type end_date: datetime
    :param value:
    :type value: float
    :param unit_id:
    :type unit_id: int
    :param unit_code:  <span class='property-internal'>Must be between 0 and
     16 characters</span> <span class='property-internal'>Must be between 0 and
     16 characters</span>
    :type unit_code: str
    :param unit_info:  <span class='property-internal'>Must be between 0 and
     32 characters</span> <span class='property-internal'>Must be between 0 and
     32 characters</span>
    :type unit_info: str
    """

    _validation = {
        'unit_code': {'max_length': 16, 'min_length': 0},
        'unit_info': {'max_length': 32, 'min_length': 0},
    }

    _attribute_map = {
        'place_size_id': {'key': 'placeSizeId', 'type': 'int'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'value': {'key': 'value', 'type': 'float'},
        'unit_id': {'key': 'unitId', 'type': 'int'},
        'unit_code': {'key': 'unitCode', 'type': 'str'},
        'unit_info': {'key': 'unitInfo', 'type': 'str'},
    }

    def __init__(self, place_size_id=None, begin_date=None, end_date=None, value=None, unit_id=None, unit_code=None, unit_info=None):
        super(PlaceSizeChild, self).__init__()
        self.place_size_id = place_size_id
        self.begin_date = begin_date
        self.end_date = end_date
        self.value = value
        self.unit_id = unit_id
        self.unit_code = unit_code
        self.unit_info = unit_info
