# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillActionSplit(Model):
    """BillActionSplit.

    :param ids: List of billIds that need to be split <span
     class='property-internal'>Cannot be Empty</span>
    :type ids: list[int]
    :param note: Optional note/comment <span class='property-internal'>Must be
     between 0 and 255 characters</span>
    :type note: str
    :param batch_settings: Optional BatchSettings. If provided the batch will
     be created with the settings in here.
     The bills generated will inherit bill headers (accounting period, invoice
     number, control code, etc ) from the batch
    :type batch_settings: ~energycap.sdk.models.BatchCreate
    """

    _validation = {
        'note': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'ids': {'key': 'ids', 'type': '[int]'},
        'note': {'key': 'note', 'type': 'str'},
        'batch_settings': {'key': 'batchSettings', 'type': 'BatchCreate'},
    }

    def __init__(self, ids=None, note=None, batch_settings=None):
        super(BillActionSplit, self).__init__()
        self.ids = ids
        self.note = note
        self.batch_settings = batch_settings
