# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class InputResponse(Model):
    """InputResponse.

    :param name:
    :type name: str
    :param prompt:
    :type prompt: str
    :param help_tag:
    :type help_tag: str
    :param default_value:
    :type default_value: str
    :param calculation:
    :type calculation: int
    :param is_block:
    :type is_block: bool
    :param data_type:
    :type data_type: int
    :param display_order:
    :type display_order: int
    :param observation_type:
    :type observation_type: ~energycap.sdk.models.ObservationTypeChild
    :param unit:
    :type unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'prompt': {'key': 'prompt', 'type': 'str'},
        'help_tag': {'key': 'helpTag', 'type': 'str'},
        'default_value': {'key': 'defaultValue', 'type': 'str'},
        'calculation': {'key': 'calculation', 'type': 'int'},
        'is_block': {'key': 'isBlock', 'type': 'bool'},
        'data_type': {'key': 'dataType', 'type': 'int'},
        'display_order': {'key': 'displayOrder', 'type': 'int'},
        'observation_type': {'key': 'observationType', 'type': 'ObservationTypeChild'},
        'unit': {'key': 'unit', 'type': 'UnitChild'},
    }

    def __init__(self, name=None, prompt=None, help_tag=None, default_value=None, calculation=None, is_block=None, data_type=None, display_order=None, observation_type=None, unit=None):
        super(InputResponse, self).__init__()
        self.name = name
        self.prompt = prompt
        self.help_tag = help_tag
        self.default_value = default_value
        self.calculation = calculation
        self.is_block = is_block
        self.data_type = data_type
        self.display_order = display_order
        self.observation_type = observation_type
        self.unit = unit
