# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Setup(Model):
    """Setup.

    :param type:
    :type type: int
    :param sheet_type:
    :type sheet_type: str
    :param action:
    :type action: str
    :param success:
    :type success: int
    :param failure:
    :type failure: int
    :param skip:
    :type skip: int
    :param kickout:
    :type kickout: str
    :param start:
    :type start: datetime
    :param finish:
    :type finish: datetime
    """

    _attribute_map = {
        'type': {'key': 'type', 'type': 'int'},
        'sheet_type': {'key': 'sheetType', 'type': 'str'},
        'action': {'key': 'action', 'type': 'str'},
        'success': {'key': 'success', 'type': 'int'},
        'failure': {'key': 'failure', 'type': 'int'},
        'skip': {'key': 'skip', 'type': 'int'},
        'kickout': {'key': 'kickout', 'type': 'str'},
        'start': {'key': 'start', 'type': 'iso-8601'},
        'finish': {'key': 'finish', 'type': 'iso-8601'},
    }

    def __init__(self, type=None, sheet_type=None, action=None, success=None, failure=None, skip=None, kickout=None, start=None, finish=None):
        super(Setup, self).__init__()
        self.type = type
        self.sheet_type = sheet_type
        self.action = action
        self.success = success
        self.failure = failure
        self.skip = skip
        self.kickout = kickout
        self.start = start
        self.finish = finish
