# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TaskEdit(Model):
    """TaskEdit.

    :param task_note:  <span class='property-internal'>Required</span>
    :type task_note: str
    """

    _validation = {
        'task_note': {'required': True},
    }

    _attribute_map = {
        'task_note': {'key': 'taskNote', 'type': 'str'},
    }

    def __init__(self, task_note):
        super(TaskEdit, self).__init__()
        self.task_note = task_note
