# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RouteSearchLogicalDevice(Model):
    """RouteSearchLogicalDevice.

    :param logical_device_id: The logical device identifier
    :type logical_device_id: int
    :param logical_device_code: The logical device code
    :type logical_device_code: str
    :param logical_device_info: The logical device info
    :type logical_device_info: str
    :param commodity: The commodity of the logical device
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param meter_id: The meter identifier
    :type meter_id: int
    :param active: Indicates if the meter is active or inactive
    :type active: bool
    :param logical_device_type_id: The logical device type identifier
    :type logical_device_type_id: int
    """

    _attribute_map = {
        'logical_device_id': {'key': 'logicalDeviceId', 'type': 'int'},
        'logical_device_code': {'key': 'logicalDeviceCode', 'type': 'str'},
        'logical_device_info': {'key': 'logicalDeviceInfo', 'type': 'str'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'active': {'key': 'active', 'type': 'bool'},
        'logical_device_type_id': {'key': 'logicalDeviceTypeId', 'type': 'int'},
    }

    def __init__(self, logical_device_id=None, logical_device_code=None, logical_device_info=None, commodity=None, meter_id=None, active=None, logical_device_type_id=None):
        super(RouteSearchLogicalDevice, self).__init__()
        self.logical_device_id = logical_device_id
        self.logical_device_code = logical_device_code
        self.logical_device_info = logical_device_info
        self.commodity = commodity
        self.meter_id = meter_id
        self.active = active
        self.logical_device_type_id = logical_device_type_id
