# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Message(Model):
    """This class represents a message from the savings processor.

    :param message_type:
    :type message_type: str
    :param message:
    :type message: str
    """

    _attribute_map = {
        'message_type': {'key': 'messageType', 'type': 'str'},
        'message': {'key': 'message', 'type': 'str'},
    }

    def __init__(self, message_type=None, message=None):
        super(Message, self).__init__()
        self.message_type = message_type
        self.message = message
