# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ObservationMethod(Model):
    """ObservationMethod.

    :param observation_method_id: The observation method identifier
    :type observation_method_id: int
    :param observation_method_code: The observation method code
    :type observation_method_code: str
    :param observation_method_info: The observation method info
    :type observation_method_info: str
    """

    _attribute_map = {
        'observation_method_id': {'key': 'observationMethodId', 'type': 'int'},
        'observation_method_code': {'key': 'observationMethodCode', 'type': 'str'},
        'observation_method_info': {'key': 'observationMethodInfo', 'type': 'str'},
    }

    def __init__(self, observation_method_id=None, observation_method_code=None, observation_method_info=None):
        super(ObservationMethod, self).__init__()
        self.observation_method_id = observation_method_id
        self.observation_method_code = observation_method_code
        self.observation_method_info = observation_method_info
