# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReadingRouteResponse(Model):
    """ReadingRouteResponse.

    :param channel: Data representing the channel containing the reading
    :type channel: ~energycap.sdk.models.ChannelResponse
    :param previous_reading: The most recent reading previous to the current
     reading
    :type previous_reading: ~energycap.sdk.models.ReadingChild
    :param reading: Data representing the reading
    :type reading: ~energycap.sdk.models.ReadingChild
    :param display_order: The display order of the meter on the route
    :type display_order: int
    """

    _attribute_map = {
        'channel': {'key': 'channel', 'type': 'ChannelResponse'},
        'previous_reading': {'key': 'previousReading', 'type': 'ReadingChild'},
        'reading': {'key': 'reading', 'type': 'ReadingChild'},
        'display_order': {'key': 'displayOrder', 'type': 'int'},
    }

    def __init__(self, channel=None, previous_reading=None, reading=None, display_order=None):
        super(ReadingRouteResponse, self).__init__()
        self.channel = channel
        self.previous_reading = previous_reading
        self.reading = reading
        self.display_order = display_order
