# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ListCreateResponse(Model):
    """ListCreateResponse.

    :param list_id:
    :type list_id: int
    :param list_info:
    :type list_info: str
    :param list_description:
    :type list_description: str
    :param list_type:
    :type list_type: ~energycap.sdk.models.ListTypeChild
    :param user:
    :type user: ~energycap.sdk.models.UserChild
    :param shared_list:
    :type shared_list: bool
    """

    _attribute_map = {
        'list_id': {'key': 'listId', 'type': 'int'},
        'list_info': {'key': 'listInfo', 'type': 'str'},
        'list_description': {'key': 'listDescription', 'type': 'str'},
        'list_type': {'key': 'listType', 'type': 'ListTypeChild'},
        'user': {'key': 'user', 'type': 'UserChild'},
        'shared_list': {'key': 'sharedList', 'type': 'bool'},
    }

    def __init__(self, list_id=None, list_info=None, list_description=None, list_type=None, user=None, shared_list=None):
        super(ListCreateResponse, self).__init__()
        self.list_id = list_id
        self.list_info = list_info
        self.list_description = list_description
        self.list_type = list_type
        self.user = user
        self.shared_list = shared_list
