# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RateVersionResponse(Model):
    """RateVersionResponse.

    :param version_id:
    :type version_id: int
    :param begin_date:
    :type begin_date: datetime
    :param end_date:
    :type end_date: datetime
    :param created_date:
    :type created_date: datetime
    :param modified_date:
    :type modified_date: datetime
    :param note:
    :type note: str
    :param created_by:
    :type created_by: ~energycap.sdk.models.UserChild
    :param modified_by:
    :type modified_by: ~energycap.sdk.models.UserChild
    :param rate_properties:
    :type rate_properties: list[~energycap.sdk.models.InputResponse]
    :param meter_details:
    :type meter_details: list[~energycap.sdk.models.InputResponse]
    :param bill_calculations:
    :type bill_calculations: list[~energycap.sdk.models.InputResponse]
    :param meter_properties:
    :type meter_properties: list[~energycap.sdk.models.InputResponse]
    :param account_properties:
    :type account_properties: list[~energycap.sdk.models.InputResponse]
    """

    _attribute_map = {
        'version_id': {'key': 'versionId', 'type': 'int'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
        'modified_date': {'key': 'modifiedDate', 'type': 'iso-8601'},
        'note': {'key': 'note', 'type': 'str'},
        'created_by': {'key': 'createdBy', 'type': 'UserChild'},
        'modified_by': {'key': 'modifiedBy', 'type': 'UserChild'},
        'rate_properties': {'key': 'rateProperties', 'type': '[InputResponse]'},
        'meter_details': {'key': 'meterDetails', 'type': '[InputResponse]'},
        'bill_calculations': {'key': 'billCalculations', 'type': '[InputResponse]'},
        'meter_properties': {'key': 'meterProperties', 'type': '[InputResponse]'},
        'account_properties': {'key': 'accountProperties', 'type': '[InputResponse]'},
    }

    def __init__(self, version_id=None, begin_date=None, end_date=None, created_date=None, modified_date=None, note=None, created_by=None, modified_by=None, rate_properties=None, meter_details=None, bill_calculations=None, meter_properties=None, account_properties=None):
        super(RateVersionResponse, self).__init__()
        self.version_id = version_id
        self.begin_date = begin_date
        self.end_date = end_date
        self.created_date = created_date
        self.modified_date = modified_date
        self.note = note
        self.created_by = created_by
        self.modified_by = modified_by
        self.rate_properties = rate_properties
        self.meter_details = meter_details
        self.bill_calculations = bill_calculations
        self.meter_properties = meter_properties
        self.account_properties = account_properties
