# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillIdsBillAlertBulkRequest(Model):
    """BillIdsBillAlertBulkRequest.

    :param bill_ids:  <span class='property-internal'>Cannot be Empty</span>
    :type bill_ids: list[int]
    :param alert_severity_info:
    :type alert_severity_info: str
    :param alert_status_info:  <span class='property-internal'>One of problem,
     fixed, ignored </span>
    :type alert_status_info: str
    :param comment:  <span class='property-internal'>Must be between 0 and 255
     characters</span>
    :type comment: str
    """

    _validation = {
        'comment': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'bill_ids': {'key': 'billIds', 'type': '[int]'},
        'alert_severity_info': {'key': 'alertSeverityInfo', 'type': 'str'},
        'alert_status_info': {'key': 'alertStatusInfo', 'type': 'str'},
        'comment': {'key': 'comment', 'type': 'str'},
    }

    def __init__(self, bill_ids=None, alert_severity_info=None, alert_status_info=None, comment=None):
        super(BillIdsBillAlertBulkRequest, self).__init__()
        self.bill_ids = bill_ids
        self.alert_severity_info = alert_severity_info
        self.alert_status_info = alert_status_info
        self.comment = comment
