# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillHeaderUpdateResponseChild(Model):
    """BillHeaderUpdateResponseChild.

    :param bill_id:
    :type bill_id: int
    :param is_updated:
    :type is_updated: bool
    """

    _attribute_map = {
        'bill_id': {'key': 'billId', 'type': 'int'},
        'is_updated': {'key': 'isUpdated', 'type': 'bool'},
    }

    def __init__(self, bill_id=None, is_updated=None):
        super(BillHeaderUpdateResponseChild, self).__init__()
        self.bill_id = bill_id
        self.is_updated = is_updated
