# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RouteResponse(Model):
    """RouteResponse.

    :param route_id: The route identifier
    :type route_id: int
    :param route_info: The route info
    :type route_info: str
    :param route_code: The route code
    :type route_code: str
    :param last_imported: The date and time of the last import
    :type last_imported: datetime
    :param last_exported: The date and time of the last export
    :type last_exported: datetime
    :param last_reading: The date and time and of the last reading
    :type last_reading: datetime
    :param meters: An array of meters belonging to the route
    :type meters: list[~energycap.sdk.models.RouteMeterChild]
    """

    _attribute_map = {
        'route_id': {'key': 'routeId', 'type': 'int'},
        'route_info': {'key': 'routeInfo', 'type': 'str'},
        'route_code': {'key': 'routeCode', 'type': 'str'},
        'last_imported': {'key': 'lastImported', 'type': 'iso-8601'},
        'last_exported': {'key': 'lastExported', 'type': 'iso-8601'},
        'last_reading': {'key': 'lastReading', 'type': 'iso-8601'},
        'meters': {'key': 'meters', 'type': '[RouteMeterChild]'},
    }

    def __init__(self, route_id=None, route_info=None, route_code=None, last_imported=None, last_exported=None, last_reading=None, meters=None):
        super(RouteResponse, self).__init__()
        self.route_id = route_id
        self.route_info = route_info
        self.route_code = route_code
        self.last_imported = last_imported
        self.last_exported = last_exported
        self.last_reading = last_reading
        self.meters = meters
